summaryrefslogtreecommitdiffstats
path: root/kooka
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
commit3c5631f74d1c75204f950140331e10f739082ee9 (patch)
treea2811ff6c81d3c771745cde47734e65b1da3d806 /kooka
parent6adb71382c3d5277c3dcbc4ec24c5ff36b4c07ef (diff)
downloadtdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.tar.gz
tdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kooka')
-rw-r--r--kooka/CHANGES2
-rw-r--r--kooka/img_saver.cpp20
-rw-r--r--kooka/kocrbase.cpp18
-rw-r--r--kooka/kocrbase.h2
-rw-r--r--kooka/kocrgocr.cpp4
-rw-r--r--kooka/kocrkadmos.cpp8
-rw-r--r--kooka/kocrkadmos.h2
-rw-r--r--kooka/kocrocrad.cpp4
-rw-r--r--kooka/kooka.cpp8
-rw-r--r--kooka/kooka.h6
-rw-r--r--kooka/kookapref.cpp2
-rw-r--r--kooka/kookapref.h4
-rw-r--r--kooka/kookaview.cpp4
-rw-r--r--kooka/kookaview.h4
-rw-r--r--kooka/ksaneocr.cpp8
-rw-r--r--kooka/ksaneocr.h4
-rw-r--r--kooka/scanpackager.cpp12
-rw-r--r--kooka/scanpackager.h10
-rw-r--r--kooka/thumbview.cpp14
-rw-r--r--kooka/thumbview.h8
20 files changed, 72 insertions, 72 deletions
diff --git a/kooka/CHANGES b/kooka/CHANGES
index 9b15cab5..45997a77 100644
--- a/kooka/CHANGES
+++ b/kooka/CHANGES
@@ -17,7 +17,7 @@ scanned with about 150 dpi.
* Reworked the ocr integration: Nice start- and finish-dialog,
animated status image, opening a text editor with the result text
- via mime mechanism of KDE (KRun). OCR-Parameter get stored via KConfig.
+ via mime mechanism of KDE (KRun). OCR-Parameter get stored via TDEConfig.
OCR may be performed on the entire image or the selection.
* Reworked the save assistant: New layout and fully KDE2-Compliant.
diff --git a/kooka/img_saver.cpp b/kooka/img_saver.cpp
index 229194af..5c61cd31 100644
--- a/kooka/img_saver.cpp
+++ b/kooka/img_saver.cpp
@@ -269,11 +269,11 @@ void ImgSaver::createDir( const TQString& dir )
{
KURL url( dir );
- if( ! KIO::NetAccess::exists(url, false, 0) )
+ if( ! TDEIO::NetAccess::exists(url, false, 0) )
{
kdDebug(28000) << "Wrn: Directory <" << dir << "> does not exist -> try to create !" << endl;
// if( mkdir( TQFile::encodeName( dir ), S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH ) != 0 )
- if( KIO::mkdir( KURL(dir)))
+ if( TDEIO::mkdir( KURL(dir)))
{
KMessageBox::sorry(0, i18n("The folder\n%1\n does not exist and could not be created;\n"
"please check the permissions.").arg(dir));
@@ -335,7 +335,7 @@ ImgSaveStat ImgSaver::saveImage( TQImage *image )
kdDebug(28000) << "saveImage: Directory is " << directory << endl;
TQString filename = createFilename( format );
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
konf->setGroup( OP_FILE_GROUP );
if( konf->readBoolEntry( OP_ASK_FILENAME, false ) )
@@ -425,7 +425,7 @@ ImgSaveStat ImgSaver::saveImage( TQImage *image, const KURL& filename, const TQS
TQString ImgSaver::findFormat( picType type )
{
TQString format;
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
konf->setGroup( OP_FILE_GROUP );
if( type == PT_THUMBNAIL )
@@ -552,7 +552,7 @@ bool ImgSaver::isRememberedFormat( picType type, TQString format ) const
TQString ImgSaver::getFormatForType( picType type ) const
{
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
TQ_CHECK_PTR( konf );
konf->setGroup( OP_FILE_GROUP );
@@ -582,7 +582,7 @@ TQString ImgSaver::getFormatForType( picType type ) const
void ImgSaver::storeFormatForType( picType type, TQString format, bool ask )
{
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
TQ_CHECK_PTR( konf );
konf->setGroup( OP_FILE_GROUP );
@@ -691,7 +691,7 @@ ImgSaveStat ImgSaver::save( TQImage *image, const TQString &filename,
void ImgSaver::readConfig( void )
{
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
TQ_CHECK_PTR( konf );
konf->setGroup( OP_FILE_GROUP );
ask_for_format = konf->readBoolEntry( OP_FILE_ASK_FORMAT, true );
@@ -794,13 +794,13 @@ bool ImgSaver::renameImage( const KURL& fromUrl, KURL& toUrl, bool askExt, TQWi
bool success = false;
- if( KIO::NetAccess::exists( targetUrl, false,0 ) )
+ if( TDEIO::NetAccess::exists( targetUrl, false,0 ) )
{
kdDebug(28000)<< "Target already exists - can not copy" << endl;
}
else
{
- if( KIO::file_move(fromUrl, targetUrl) )
+ if( TDEIO::file_move(fromUrl, targetUrl) )
{
success = true;
}
@@ -886,7 +886,7 @@ bool ImgSaver::copyImage( const KURL& fromUrl, const KURL& toUrl, TQWidget *over
}
}
- KIO::Job *copyjob = KIO::copy( fromUrl, targetUrl, false );
+ TDEIO::Job *copyjob = TDEIO::copy( fromUrl, targetUrl, false );
return( copyjob ? true : false );
}
diff --git a/kooka/kocrbase.h b/kooka/kocrbase.h
index 76456214..f56d08c7 100644
--- a/kooka/kocrbase.h
+++ b/kooka/kocrbase.h
@@ -134,7 +134,7 @@ protected slots:
virtual void slWantSpellcheck( bool wantIt );
private slots:
- virtual void slPreviewResult( KIO::Job* );
+ virtual void slPreviewResult( TDEIO::Job* );
virtual void slGotPreview( const KFileItem*, const TQPixmap& );
private:
diff --git a/kooka/kocrgocr.cpp b/kooka/kocrgocr.cpp
index fc7e45a7..c4c34d4a 100644
--- a/kooka/kocrgocr.cpp
+++ b/kooka/kocrgocr.cpp
@@ -93,7 +93,7 @@ EngineError KGOCRDialog::setupGui()
TQVBox *page = ocrPage();
TQ_CHECK_PTR( page );
- KConfig *conf = TDEGlobal::config ();
+ TDEConfig *conf = TDEGlobal::config ();
conf->setGroup( CFG_GROUP_OCR_DIA );
//Qt::Horizontal line
@@ -179,7 +179,7 @@ KGOCRDialog::~KGOCRDialog()
void KGOCRDialog::writeConfig( void )
{
- KConfig *conf = TDEGlobal::config ();
+ TDEConfig *conf = TDEGlobal::config ();
conf->setGroup( CFG_GROUP_OCR_DIA );
conf->writeEntry( CFG_GOCR_BINARY, TQString(getOCRCmd()));
diff --git a/kooka/kocrkadmos.cpp b/kooka/kocrkadmos.cpp
index 58191256..013b5e1a 100644
--- a/kooka/kocrkadmos.cpp
+++ b/kooka/kocrkadmos.cpp
@@ -236,8 +236,8 @@ EngineError KadmosDialog::findClassifierPath()
KStandardDirs stdDir;
EngineError err = ENG_OK;
- KConfig *conf = TDEGlobal::config ();
- KConfigGroupSaver gs( conf, CFG_GROUP_KADMOS );
+ TDEConfig *conf = TDEGlobal::config ();
+ TDEConfigGroupSaver gs( conf, CFG_GROUP_KADMOS );
m_customClassifierPath = conf->readPathEntry( CFG_KADMOS_CLASSIFIER_PATH );
#if 0
@@ -341,8 +341,8 @@ void KadmosDialog::slFontChanged( int id )
{
m_cbLang->clear();
- KConfig *conf = TDEGlobal::config ();
- KConfigGroupSaver gs( conf, CFG_GROUP_KADMOS );
+ TDEConfig *conf = TDEGlobal::config ();
+ TDEConfigGroupSaver gs( conf, CFG_GROUP_KADMOS );
diff --git a/kooka/kocrkadmos.h b/kooka/kocrkadmos.h
index 02308edf..4d6d5ce9 100644
--- a/kooka/kocrkadmos.h
+++ b/kooka/kocrkadmos.h
@@ -41,7 +41,7 @@
class KScanCombo;
class TQWidget;
class TQButtonGroup;
-class KConfig;
+class TDEConfig;
class TQCheckBox;
class KSpellConfig;
class TQRadioButton;
diff --git a/kooka/kocrocrad.cpp b/kooka/kocrocrad.cpp
index 340bc4ad..f037e4b2 100644
--- a/kooka/kocrocrad.cpp
+++ b/kooka/kocrocrad.cpp
@@ -104,7 +104,7 @@ EngineError ocradDialog::setupGui()
TQVBox *page = ocrPage();
TQ_CHECK_PTR( page );
- KConfig *conf = TDEGlobal::config ();
+ TDEConfig *conf = TDEGlobal::config ();
conf->setGroup( CFG_GROUP_OCR_DIA );
//Qt::Horizontal line
@@ -177,7 +177,7 @@ ocradDialog::~ocradDialog()
void ocradDialog::writeConfig( void )
{
- KConfig *conf = TDEGlobal::config ();
+ TDEConfig *conf = TDEGlobal::config ();
conf->setGroup( CFG_GROUP_OCR_DIA );
conf->writeEntry( CFG_OCRAD_BINARY, TQString(getOCRCmd()));
diff --git a/kooka/kooka.cpp b/kooka/kooka.cpp
index 8d944913..a1c183bb 100644
--- a/kooka/kooka.cpp
+++ b/kooka/kooka.cpp
@@ -75,7 +75,7 @@ Kooka::Kooka( const TQCString& deviceToUse)
setXMLFile( "kookaui.rc", true );
setAcceptDrops(false); // Waba: Not (yet?) supported
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
readDockConfig ( konf, DOCK_SIZES );
// then, setup our actions
@@ -109,7 +109,7 @@ void Kooka::createMyGUI( KParts::Part *part )
Kooka::~Kooka()
{
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
m_view->slCloseScanDevice();
writeDockConfig ( konf, DOCK_SIZES );
delete m_printer;
@@ -271,7 +271,7 @@ actionCollection());
}
-void Kooka::saveProperties(KConfig *config)
+void Kooka::saveProperties(TDEConfig *config)
{
// the 'config' object points to the session managed
// config file. anything you write here will be available
@@ -285,7 +285,7 @@ void Kooka::saveProperties(KConfig *config)
m_view->saveProperties( config );
}
-void Kooka::readProperties(KConfig *config)
+void Kooka::readProperties(TDEConfig *config)
{
(void) config;
// the 'config' object points to the session managed
diff --git a/kooka/kookapref.cpp b/kooka/kookapref.cpp
index d6bb729b..e0996966 100644
--- a/kooka/kookapref.cpp
+++ b/kooka/kookapref.cpp
@@ -200,7 +200,7 @@ TQString KookaPreferences::tryFindBinary( const TQString& bin, const TQString& c
{
/* First check the config files for an entry */
- KConfig *cfg = TDEGlobal::config();
+ TDEConfig *cfg = TDEGlobal::config();
cfg->setGroup(CFG_GROUP_OCR_DIA);
TQString res = cfg->readPathEntry( configKey /* CFG_GOCR_BINARY */, "notFound" );
diff --git a/kooka/kookapref.h b/kooka/kookapref.h
index d57d3ff2..be7954c1 100644
--- a/kooka/kookapref.h
+++ b/kooka/kookapref.h
@@ -29,7 +29,7 @@
#include <kdialogbase.h>
#include <tqframe.h>
-class KConfig;
+class TDEConfig;
class TQLabel;
class KIntNumInput;
class KColorButton;
@@ -78,7 +78,7 @@ private:
TQCheckBox *cbSkipFormatAsk;
TQCheckBox *cbFilenameAsk;
TQCheckBox *cbShowScannerSelection;
- KConfig *konf;
+ TDEConfig *konf;
TQCheckBox *cbReadStartupImage;
KIntNumInput *m_thumbWidth;
diff --git a/kooka/kookaview.cpp b/kooka/kookaview.cpp
index 45f101f9..9be6b974 100644
--- a/kooka/kookaview.cpp
+++ b/kooka/kookaview.cpp
@@ -438,7 +438,7 @@ void KookaView::loadStartupImage( void )
kdDebug( 28000) << "Starting to load startup image" << endl;
/* Now set the configured stuff */
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
if( konf )
{
konf->setGroup(GROUP_STARTUP);
@@ -939,7 +939,7 @@ void KookaView::updateCurrImage( TQImage& img )
}
-void KookaView::saveProperties(KConfig *config)
+void KookaView::saveProperties(TDEConfig *config)
{
kdDebug(28000) << "Saving Properties for KookaView !" << endl;
config->setGroup( GROUP_STARTUP );
diff --git a/kooka/kookaview.h b/kooka/kookaview.h
index b4d4a5df..3b976fc0 100644
--- a/kooka/kookaview.h
+++ b/kooka/kookaview.h
@@ -48,7 +48,7 @@
class KDockWidget;
class TQPainter;
class KSANEOCR;
-class KConfig;
+class TDEConfig;
class KPrinter;
class KComboBox;
class KAction;
@@ -153,7 +153,7 @@ public slots:
void startOCR( KookaImage* );
void slCloseScanDevice();
- void saveProperties( KConfig* );
+ void saveProperties( TDEConfig* );
/**
* slot to select the scanner device. Does all the work with selection
diff --git a/kooka/ksaneocr.cpp b/kooka/ksaneocr.cpp
index bbaa15a8..9298aa75 100644
--- a/kooka/ksaneocr.cpp
+++ b/kooka/ksaneocr.cpp
@@ -68,7 +68,7 @@
* thread save unfortunately. See slotKadmosResult-comments for more information
*/
-KSANEOCR::KSANEOCR( TQWidget*, KConfig *cfg ):
+KSANEOCR::KSANEOCR( TQWidget*, TDEConfig *cfg ):
m_ocrProcessDia(0L),
daemon(0L),
visibleOCRRunning(false),
@@ -85,7 +85,7 @@ KSANEOCR::KSANEOCR( TQWidget*, KConfig *cfg ):
m_applyFilter(false),
m_unlinkORF(true)
{
- KConfig *konf = TDEGlobal::config ();
+ TDEConfig *konf = TDEGlobal::config ();
m_ocrEngine = OCRAD;
m_img = 0L;
m_tmpFile = 0L;
@@ -403,8 +403,8 @@ void KSANEOCR::startOCRAD( )
*daemon << TQString("-l");
*daemon << TQString::number( ocrDia->layoutDetectionMode());
- KConfig *konf = TDEGlobal::config ();
- KConfigGroupSaver( konf, CFG_GROUP_OCRAD );
+ TDEConfig *konf = TDEGlobal::config ();
+ TDEConfigGroupSaver( konf, CFG_GROUP_OCRAD );
TQString format = konf->readEntry( CFG_OCRAD_FORMAT, "utf8");
*daemon << TQString("-F");
diff --git a/kooka/ksaneocr.h b/kooka/ksaneocr.h
index 7d312aaf..d01be364 100644
--- a/kooka/ksaneocr.h
+++ b/kooka/ksaneocr.h
@@ -59,7 +59,7 @@ class TQStringList;
class KSpell;
class KSpellConfig;
class ImageCanvas;
-class KConfig;
+class TDEConfig;
// class ocrWord;
// class ocrPage;
@@ -79,7 +79,7 @@ class KSANEOCR : public TQObject
public:
enum OCREngines{ GOCR, OCRAD, KADMOS };
- KSANEOCR( TQWidget*, KConfig *);
+ KSANEOCR( TQWidget*, TDEConfig *);
~KSANEOCR();
bool startOCRVisible( TQWidget* parent=0);
diff --git a/kooka/scanpackager.cpp b/kooka/scanpackager.cpp
index 71b97246..24b815cb 100644
--- a/kooka/scanpackager.cpp
+++ b/kooka/scanpackager.cpp
@@ -255,7 +255,7 @@ void ScanPackager::slotDecorate( KFileTreeViewItem* item )
item->setPixmap( 0, m_floppyPixmap );
if ( kfi )
{
- item->setText(1, KIO::convertSize( kfi->size() ));
+ item->setText(1, TDEIO::convertSize( kfi->size() ));
}
}
@@ -1050,13 +1050,13 @@ void ScanPackager::slotUrlsDropped( TQWidget*, TQDropEvent* ev, KURL::List& urls
}
if ( ev->action() == TQDropEvent::Move )
- copyjob = KIO::move( urls, copyTo, true );
+ copyjob = TDEIO::move( urls, copyTo, true );
else
- copyjob = KIO::copy( urls, copyTo, true );
+ copyjob = TDEIO::copy( urls, copyTo, true );
}
}
-void ScanPackager::slotCanceled( KIO::Job* )
+void ScanPackager::slotCanceled( TDEIO::Job* )
{
kdDebug(28000) << i18n("Canceled by user") << endl;
}
@@ -1145,7 +1145,7 @@ void ScanPackager::slotDeleteItems( )
/* Since we are currently talking about local files here, NetAccess is OK */
if( result == KMessageBox::Continue )
{
- if( KIO::NetAccess::del( urlToDel, 0 ))
+ if( TDEIO::NetAccess::del( urlToDel, 0 ))
{
if( nextToSelect )
setSelected( nextToSelect, true );
@@ -1193,7 +1193,7 @@ void ScanPackager::slotCreateFolder( )
*/
slotSetNextUrlToSelect( url );
- if( ! KIO::NetAccess::mkdir( url, 0, -1 ))
+ if( ! TDEIO::NetAccess::mkdir( url, 0, -1 ))
{
kdDebug(28000) << "ERR: creation of " << url.prettyURL() << " failed !" << endl;
}
diff --git a/kooka/scanpackager.h b/kooka/scanpackager.h
index d67efe08..0f57b7fc 100644
--- a/kooka/scanpackager.h
+++ b/kooka/scanpackager.h
@@ -59,15 +59,15 @@ class JobDescription
public:
enum JobType { NoJob, ImportJob, RenameJob, ExportJob };
JobDescription():jobType( NoJob ), kioJob(0L), pitem(0L) {}
- JobDescription( KIO::Job* kiojob, KFileTreeViewItem *new_item, JobType type ) :
+ JobDescription( TDEIO::Job* kiojob, KFileTreeViewItem *new_item, JobType type ) :
jobType(type), kioJob(kiojob), pitem(new_item) {}
JobType type( void ) { return( jobType ); }
KFileTreeViewItem *item( void ) { return( pitem ); }
- KIO::Job* job( void ){ return( kioJob ); }
+ TDEIO::Job* job( void ){ return( kioJob ); }
private:
JobType jobType;
- KIO::Job* kioJob;
+ TDEIO::Job* kioJob;
KFileTreeViewItem* pitem;
};
@@ -95,7 +95,7 @@ public slots:
void slotExportFile( );
void slotImportFile();
- void slotCanceled(KIO::Job*);
+ void slotCanceled(TDEIO::Job*);
void slotCurrentImageChanged( TQImage* );
void slotDecorate( KFileTreeViewItem* );
@@ -149,7 +149,7 @@ private:
TQString m_currImportDir;
TQString m_currCopyDir;
TQString currSelectedDir;
- KIO::Job *copyjob;
+ TDEIO::Job *copyjob;
int img_counter;
TQPopupMenu *m_contextMenu;
diff --git a/kooka/thumbview.h b/kooka/thumbview.h
index ae0b85af..c4c58323 100644
--- a/kooka/thumbview.h
+++ b/kooka/thumbview.h
@@ -41,7 +41,7 @@
#include <kfileitem.h>
#include <kfileiconview.h>
-/* KConfig group definitions */
+/* TDEConfig group definitions */
#define MARGIN_COLOR1 "MarginColor1"
#define MARGIN_COLOR2 "MarginColor2"
#define PIXMAP_WIDTH "pixmapWidth"
@@ -54,7 +54,7 @@
class TQPixmap;
class TQListViewItem;
class KProgress;
-class KIO::PreviewJob;
+class TDEIO::PreviewJob;
class ThumbView: public TQVBox /* KIconView */
{
@@ -99,7 +99,7 @@ public slots:
void slNewFileItems( const KFileItemList& );
void slGotPreview( const KFileItem*, const TQPixmap& );
- void slPreviewResult( KIO::Job* );
+ void slPreviewResult( TDEIO::Job* );
/**
* This connects to the IconView's executed signal and tells the packager
@@ -146,7 +146,7 @@ private:
TQColor m_marginColor2;
TQString m_bgImg;
int m_cntJobsStarted;
- KIO::PreviewJob *m_job;
+ TDEIO::PreviewJob *m_job;
KFileItemList m_pendingJobs;
};
diff --git a/kooka/kocrbase.cpp b/kooka/kocrbase.cpp
index 171d1b4d..168e9e63 100644
--- a/kooka/kocrbase.cpp
+++ b/kooka/kocrbase.cpp
@@ -81,8 +81,8 @@ KOCRBase::KOCRBase( TQWidget *parent, KSpellConfig *spellConfig,
kdDebug(28000) << "OCR Base Dialog!" << endl;
// Layout-Boxes
- KConfig *konf = TDEGlobal::config ();
- KConfigGroupSaver gs( konf, CFG_OCR_KSPELL );
+ TDEConfig *konf = TDEGlobal::config ();
+ TDEConfigGroupSaver gs( konf, CFG_OCR_KSPELL );
m_userWantsSpellCheck = konf->readBoolEntry(CFG_WANT_KSPELL, true);
/* Connect signals which disable the fields and store the configuration */
@@ -237,16 +237,16 @@ void KOCRBase::introduceImage( KookaImage* img)
/* Start to create a preview job for the thumb */
KURL::List li(img->url());
- KIO::Job *m_job = KIO::filePreview(li, m_previewSize.width(),
+ TDEIO::Job *m_job = TDEIO::filePreview(li, m_previewSize.width(),
m_previewSize.height());
if( m_job )
{
- connect( m_job, TQT_SIGNAL( result( KIO::Job * )),
- this, TQT_SLOT( slPreviewResult( KIO::Job * )));
+ connect( m_job, TQT_SIGNAL( result( TDEIO::Job * )),
+ this, TQT_SLOT( slPreviewResult( TDEIO::Job * )));
connect( m_job, TQT_SIGNAL( gotPreview( const KFileItem*, const TQPixmap& )),
TQT_SLOT( slGotPreview( const KFileItem*, const TQPixmap& ) ));
/* KIO::Jo result is called in any way: Success, Failed, Error,
* thus connecting the failed is not really necessary.
*/
}
@@ -289,7 +289,7 @@ void KOCRBase::introduceImage( KookaImage* img)
m_metaBox->show();
}
-void KOCRBase::slPreviewResult(KIO::Job *job )
+void KOCRBase::slPreviewResult(TDEIO::Job *job )
{
// nothing
if( job && job->error() > 0 )
@@ -359,8 +359,8 @@ void KOCRBase::slWantSpellcheck( bool wantIt )
}
m_userWantsSpellCheck = wantIt;
- KConfig *konf = TDEGlobal::config ();
- KConfigGroupSaver gs( konf, CFG_OCR_KSPELL );
+ TDEConfig *konf = TDEGlobal::config ();
+ TDEConfigGroupSaver gs( konf, CFG_OCR_KSPELL );
konf->writeEntry( CFG_WANT_KSPELL, wantIt );
}
@@ -237,16 +237,16 @@ void KOCRBase::introduceImage( KookaImage* img)
connect( m_job, TQT_SIGNAL( gotPreview( const KFileItem*, const TQPixmap& )),
TQT_SLOT( slGotPreview( const KFileItem*, const TQPixmap& ) ));
- /* KIO::Jo result is called in any way: Success, Failed, Error,
+ /* TDEIO::Jo result is called in any way: Success, Failed, Error,
* thus connecting the failed is not really necessary.
*/
diff --git a/kooka/kooka.h b/kooka/kooka.h
index 84ff1423..634e6c53 100644
--- a/kooka/kooka.h
+++ b/kooka/kooka.h
@@ -84,14 +84,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig *);
+ void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig *);
+ void readProperties(TDEConfig *);
private slots:
@@ -84,14 +84,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties
diff --git a/kooka/thumbview.cpp b/kooka/thumbview.cpp
index a61dbb6d..d1b48045 100644
--- a/kooka/thumbview.cpp
+++ b/kooka/thumbview.cpp
@@ -86,7 +86,7 @@ ThumbView::~ThumbView()
bool ThumbView::readSettings()
{
- KConfig *cfg = TDEGlobal::config();
+ TDEConfig *cfg = TDEGlobal::config();
cfg->setGroup( THUMB_GROUP );
bool dirty = false;
@@ -385,18 +385,18 @@ void ThumbView::slNewFileItems( const KFileItemList& items )
m_cntJobsStarted = 0;
/* start a preview-job */
- m_job = KIO::filePreview(m_pendingJobs, m_pixWidth, m_pixHeight );
+ m_job = TDEIO::filePreview(m_pendingJobs, m_pixWidth, m_pixHeight );
if( m_job )
{
- connect( m_job, TQT_SIGNAL( result( KIO::Job * )),
- this, TQT_SLOT( slPreviewResult( KIO::Job * )));
+ connect( m_job, TQT_SIGNAL( result( TDEIO::Job * )),
+ this, TQT_SLOT( slPreviewResult( TDEIO::Job * )));
connect( m_job, TQT_SIGNAL( gotPreview( const KFileItem*, const TQPixmap& )),
TQT_SLOT( slGotPreview( const KFileItem*, const TQPixmap& ) ));
m_pendingJobs.clear();
/* KIO::Jo result is called in any way: Success, Failed, Error,
* thus connecting the failed is not really necessary.
*/
// connect( job, TQT_SIGNAL( failed( const KFileItem* )),
@@ -424,7 +424,7 @@ void ThumbView::slGotPreview( const KFileItem* newFileItem, const TQPixmap& newP
}
-void ThumbView::slPreviewResult( KIO::Job *job )
+void ThumbView::slPreviewResult( TDEIO::Job *job )
{
if( job && job->error() > 0 )
{
@@ -481,7 +481,7 @@ void ThumbView::clear()
void ThumbView::saveConfig()
{
- KConfig *cfg = TDEGlobal::config();
+ TDEConfig *cfg = TDEGlobal::config();
cfg->setGroup( THUMB_GROUP );
cfg->writeEntry( MARGIN_COLOR1, m_marginColor1 );
@@ -385,18 +385,18 @@ void ThumbView::slNewFileItems( const KFileItemList& items )
TQT_SLOT( slGotPreview( const KFileItem*, const TQPixmap& ) ));
m_pendingJobs.clear();
- /* KIO::Jo result is called in any way: Success, Failed, Error,
+ /* TDEIO::Jo result is called in any way: Success, Failed, Error,
* thus connecting the failed is not really necessary.
*/